@@ -147,6 +147,10 @@ class Selenium(Scraper):
         else:
             return None
 
+    def on_hover(self, path: str, element: any) -> None:
+        element = self.scraper.xPath(element=element, path=path)
+        ActionChains(self.scraper.scraper.driver).move_to_element(element).perform()
+
     def on_click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
         element = self.xPath(path=path, timeout=timeout)
         action = ActionChains(self.scraper.driver)
